@@ -128,7 +128,7 @@ void PackageKitNotifier::checkOfflineUpdates()
                                  {},
                                  {},
                                  KNotification::CloseOnTimeout,
-                                 QStringLiteral("org.kde.discovernotifier"));
+                                 QStringLiteral("discoverabstractnotifier"));
 
             connect(trans, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error /*error*/, const QString &details) {
                 KNotification::event(QStringLiteral("OfflineUpdateRepairFailed"),
@@ -136,9 +136,9 @@ void PackageKitNotifier::checkOfflineUpdates()
                                      xi18nc("@info", "%1<nl/>Please report this error to your distribution.", details),
                                      {},
                                      KNotification::Persistent,
-                                     QStringLiteral("org.kde.discovernotifier"));
+                                     QStringLiteral("discoverabstractnotifier"));
             });
-            connect(trans, &PackageKit::Transaction::finished, this, [] (PackageKit::Transaction::Exit status, uint runtime) {
+            connect(trans, &PackageKit::Transaction::finished, this, [](PackageKit::Transaction::Exit status, uint runtime) {
                 qInfo() << "repair finished!" << status << runtime;
                 if (status == PackageKit::Transaction::ExitSuccess) {
                     PackageKit::Daemon::global()->offline()->clearResults();
@@ -148,7 +148,7 @@ void PackageKitNotifier::checkOfflineUpdates()
                                          {},
                                          {},
                                          KNotification::CloseOnTimeout,
-                                         QStringLiteral("org.kde.discovernotifier"));
+                                         QStringLiteral("discoverabstractnotifier"));
                 }
             });
         });
@@ -157,7 +157,7 @@ void PackageKitNotifier::checkOfflineUpdates()
     } else {
         // Apparently on mobile, people are accustomed to seeing notifications
         // indicating success when a system update succeeded
-        if (isMobile){
+        if (isMobile) {
             KNotification *notification = new KNotification(QStringLiteral("OfflineUpdateSuccessful"));
             notification->setIconName(QStringLiteral("system-software-update"));
             notification->setTitle(i18n("Offline Updates"));
